@@ -10,11 +10,9 @@
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
-import mock
-
 from nose.tools import assert_false
 
-from tests import create_session, ClientHTTPStubber
+from tests import create_session, mock, ClientHTTPStubber
 
 
 def test_unsigned_operations():
